"getEstimate"(x, esttype = c("logor", "or", "logodds", "odds", "p"), se.fit = (esttype %in% c("logor", "logodds")), ci = TRUE, drop = TRUE)logor
for the log odds ratio, or for the odds ratios,
logodds for the log odds, odds for the odds
or p for the percentages.logor or logodds. Note that you can
also use the accessor se to get only the
standard errors.TRUE and
neither se nor ci is calculated, the
function returns a vector instead of an uwmwEstimate
object.uwmwEstimate object with the
requested estimate. See uwmwEstimate for
details. In case drop=TRUE and neither the standard
error nor the confidence interval is calculated, a numeric
named vector.
se.fit is
ignored. The function takes into account a possible
ordering in the object (see also
sort.uwmwRes). So take into account that you
get the estimates in the specified order. In case you want
this different, either use the function
unorder on the object first, or check if any
of the uwmw_Accessors can help you out.The argument se.fit is mainly to be used to save
calculation time. Normally there's no need to set it to
FALSE.
data(NBmat)
NBtest <- uWMW(NBmat, groups=NBgroups)
getEstimate(NBtest,'logodds')
getEstimate(NBtest,'odds',ci=0.9)
Run the code above in your browser using DataLab