"uWMW"(x, groups, housekeeping.names = NULL, transpose = FALSE, feat.names = NULL)
"uWMW"(x, feat.names = NULL, ...)
"uWMW"(x, groups, feat.names, subjects, value, ...)housekeeping.names is specified,
housekeeping normalization is considered. Otherwise overall
normalization is considered.The function uWMW can deal with data frames, matrices and
qPCRset objects from the package HTqPCR. When
using a data frame, you need to specify the arguments
groups, feat.names, subjects and
value; each one should contain the name of the
related variable in the data frame.
When using a matrix, each column is assumed to be a subject
and each row a feature. The argument groups should
contain as much values as there are columns in the matrix.
Note that the method for qPCRset objects does
nothing else but extract the data matrix and do the
analysis. You still need to specify where the groups are to
be found.
uwmw_Accessors and uwmw_Extract
for accessing the results, and volcanoplot
and forestplot for plotting them.
data(NBmat)
NBtest <- uWMW(NBmat, groups=NBgroups)
data(NBdata)
NBtest <- uWMW(x = NBdata, groups = "group", sub="subject",feat="miRNA",val="Cq")
head(NBtest)
as.matrix(NBtest)
Run the code above in your browser using DataLab