uwmwRes-class: Class uwmwRes
Description
This class represents the results of the unified
Wilcoxon-Mann-Whitney test. It contains all necessary
information for the vulcano and forest plots. For this
class a number of methods is foreseen, among which
accessors for every slot.
Slots
type:- object of class
"character", containing the type of analysis
(either H or O, see uWMW for more
details.)
housekeeping:- object of class
"character", containing either NULL or the names
of the housekeeping features used in the HME version of
uWMW.
names:- object of class
"character", containing the names of the features
that were used in the test.
logOR:- object
of class
"numeric", containing the estimated log
odds ratios from the uWMW test.
se:- object
of class
"numeric", containing the standard errors
on the estimated log odds ratios. OR:- object of class
"numeric",
containing the odds ratios estimated by the uWMW test.
This slot is accessed using the function
oddsRatio()
z.value:- object of
class
"numeric", containing the Z values related
to the odds ratios estimated by the uWMW test. These
z-values relate to the chance that a specific feature is
up- or downregulated, and are used as the basis for
determining the p values.
p.value:- object
of class
"numeric", containing the p values
related to the odds ratios estimated by the uWMW test.
These p-values relate to the chance that a specific
feature is up- or downregulated. coef:- object of class
"numeric",
containing the estimated coefficient of the PIM model
that's used in the uWMW test.
vcov:- matrix
of class
"numeric", containing the
variance-covariance matrix related to the estimated
coefficients.
id:- vector of class
"numeric", containing the sorting order of the
features. This slot is set using the function
sort
orderedBy:- character value,
indicating whether the object contains an order and if
so, based on which slot. Possible values are "none", "p",
"z", "or", "se" or "name". Defaults to "none".
groupinfo:- character vector of length 2,
indicating the groups. This slot is mainly used to show
how the probabilistic indices are calculated.